@@ -1,7 +1,7 @@
 """
 Type annotations for elb service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/)
 
 Usage::
 
@@ -35,7 +35,7 @@ __all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "Instance
 class AnyInstanceInServiceWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#anyinstanceinservicewaiter)
     """
 
     def wait(
@@ -43,18 +43,18 @@ class AnyInstanceInServiceWaiter(Boto3Waiter):
         *,
         LoadBalancerName: str,
         Instances: Sequence["InstanceTypeDef"] = ...,
-        WaiterConfig: WaiterConfigTypeDef = ...
+        WaiterConfig: "WaiterConfigTypeDef" = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#anyinstanceinservicewaiter)
         """
 
 
 class InstanceDeregisteredWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#instancederegisteredwaiter)
     """
 
     def wait(
@@ -62,18 +62,18 @@ class InstanceDeregisteredWaiter(Boto3Waiter):
         *,
         LoadBalancerName: str,
         Instances: Sequence["InstanceTypeDef"] = ...,
-        WaiterConfig: WaiterConfigTypeDef = ...
+        WaiterConfig: "WaiterConfigTypeDef" = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#instancederegisteredwaiter)
         """
 
 
 class InstanceInServiceWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#instanceinservicewaiter)
     """
 
     def wait(
@@ -81,9 +81,9 @@ class InstanceInServiceWaiter(Boto3Waiter):
         *,
         LoadBalancerName: str,
         Instances: Sequence["InstanceTypeDef"] = ...,
-        WaiterConfig: WaiterConfigTypeDef = ...
+        WaiterConfig: "WaiterConfigTypeDef" = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#instanceinservicewaiter)
         """
